Paste Omitting NA Values
paste_na_rm.RdPastes elements together while omitting NA values, returning NA only if
all values are NA.
Arguments
- ...
one or more R objects, to be converted to character vectors.
- sep
a character string to separate the terms. Not
NA_character_.- collapse
an optional character string to separate the results. Not
NA_character_. Whencollapseis a string, the result is always a string (characterof length 1).