Skip to contents

Updates data in the 'Registry of Contributor' tables of disease-ontology.org to match the curated contributor data in the DO_contributors google sheet.

Usage

update_website_contributors(contrib_path, table_id)

Arguments

contrib_path

The file path to the "Contributors" page HTML file, as a string.

table_id

The id of the table to update in the HTML file, as a string.

Value

The page's updated HTML, invisibly.