Skip to contents

Updates the data in the table on the "Use Cases" page of disease-ontology.org to match the curated use cases in the DO_uses google sheet.

Usage

update_website_use_cases(use_cases_path, table_id = "use-cases")

Arguments

use_cases_path

The file path to the "Use Cases" page HTML file, as a string.

table_id

The id of the table to update in the HTML file, as a string.

Value

The page's update HTML, invisibly.