Update 'Registry of Contributor' Tables on Web Pages
update_website_contributors.RdUpdates data in the 'Registry of Contributor' tables of disease-ontology.org to match the curated contributor data in the DO_contributors google sheet.
update_website_contributors.RdUpdates data in the 'Registry of Contributor' tables of disease-ontology.org to match the curated contributor data in the DO_contributors google sheet.